@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2018 by Peter Semiletov                                          *
+ *   2007-2019 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,7 +41,6 @@ code from qwriter:
 #include <bitset>
 #include <algorithm>
 
-
 #include <QApplication>
 #include <QClipboard>
 #include <QSettings>
@@ -54,10 +53,6 @@ code from qwriter:
 #include <QMimeData>
 #include <QTimer>
 
-
-
-
-
 #if QT_VERSION >= 0x050000
 #include <QRegularExpression>
 #endif
@@ -87,8 +82,7 @@ void CDocument::update_status()
   int x = textEdit->textCursor().position() - textEdit->textCursor().block().position() + 1;
   int y = textEdit->textCursor().block().blockNumber() + 1;
 
-  holder->l_status_bar->setText (
-                                 QString ("%1:%2").arg (
+  holder->l_status_bar->setText (QString ("%1:%2").arg (
                                  QString::number (y)).arg (
                                  QString::number (x)));
 
@@ -359,10 +353,17 @@ CDocument* CDox::get_document_by_fname (const QString &fileName)
   if (fileName.isEmpty())
      return NULL;
 
+  for (int i = 0; i < list.size(); i++)
+      {
+       CDocument *d = list[i];
+       if (d->file_name == fileName)
+              return d;
+      }
+  /*
   foreach (CDocument *d, list)
           if (d->file_name == fileName)
               return d;
-
+*/
   return NULL;
 }
 
@@ -540,14 +541,13 @@ CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDo
 
 
 #if QT_VERSION >= 0x050000
-
+//#if QT_VERSION_MAJOR >= 5
 CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTextDocument *parent, CDocument *doc, const QString &fname):
                                                                             CSyntaxHighlighter (parent, doc, fname)
 {
   document = doc;
   load_from_xml (fname);
 }
-
 #endif
 
 
@@ -580,6 +580,7 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
      return;
 
 #if QT_VERSION >= 0x050000
+//#if (QT_VERSION_MAJOR >= 5)
 
   if (settings->value ("qregexpsyntaxhl", 0).toBool())
      highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
@@ -618,7 +619,8 @@ void CDox::apply_settings_single (CDocument *d)
   d->textEdit->tab_sp_width = settings->value ("tab_sp_width", 8).toInt();
   d->textEdit->spaces_instead_of_tabs = settings->value ("spaces_instead_of_tabs", true).toBool();
 
-#if QT_VERSION >= 0x051000
+//#if QT_VERSION >= 0x051000
+#if (QT_VERSION_MAJOR >= 5 && QT_VERSION_MINOR >= 10)
 
   d->textEdit->setTabStopDistance (d->textEdit->tab_sp_width * d->textEdit->brace_width);
 
@@ -1026,13 +1028,12 @@ QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &col
 }
 
 
+
 #if QT_VERSION >= 0x050000
+//#if (QT_VERSION_MAJOR >= 5)
 
 void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 {
-// qDebug() << "CSyntaxHighlighterQRegularExpression::load_from_xml ";
-
-  //wrap = true;
   casecare = true;
   exts = "default";
   langs = "default";
@@ -1100,8 +1101,6 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                         {
                          QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
 
-                         //HighlightingRule rule;
-
                          for (int i = 0; i < keywordPatterns.size(); i++)
                               if (! keywordPatterns.at(i).isEmpty())
                                  {
@@ -1447,15 +1446,15 @@ void CDox::save_to_session (const QString &fileName)
   fname_current_session = fileName;
   QString l;
 
-  foreach (CDocument *d, list)
+  for (int i = 0; i < list.size(); i++)
+      {
+       QString t = list[i]->get_triplex();
+       if (! t.isEmpty())
           {
-           QString t = d->get_triplex();
-           if (! t.isEmpty())
-               {
-                l += t;
-                l += "\n";
-               }
+           l += t;
+           l += "\n";
           }
+      }
 
   qstring_save (fileName, l.trimmed());
 }
@@ -1470,8 +1469,9 @@ void CDox::load_from_session (const QString &fileName)
   if (l.size() < 0)
      return;
 
-  foreach (QString t, l)
-          open_file_triplex (t);
+  for (int i = 0; i < l.size(); i++)
+      open_file_triplex (l[i]);
+
 
   fname_current_session = fileName;
 }
@@ -2000,9 +2000,6 @@ void CTEAEdit::resizeEvent (QResizeEvent *e)
 
 void CTEAEdit::braceHighlight()
 {
-  //extraSelections.clear();
-  //setExtraSelections (extraSelections);
-
   brace_selection.format.setBackground (brackets_color);
 
   QTextDocument *doc = document();
@@ -2218,7 +2215,6 @@ void CTEAEdit::update_rect_sel()
 }
 
 
-
 void CTEAEdit::rect_sel_replace (const QString &s, bool insert)
 {
 /*
@@ -2733,15 +2729,6 @@ bool CDox::event (QEvent *ev)
 
 void CDox::handle_joystick_event (CJoystickAxisEvent *event)
 {
-//  CDocument *d = get_current();
-
-//  if (! d)
-  //   return;
-
-//  QTextCursor cr = d->textEdit->textCursor();
-//  if (cr.isNull())
-  //   return;
-
   QTextCursor::MoveOperation mo = QTextCursor::NoMove;
 
   if (event->axis == 1 && event->value < 0) //up
@@ -2758,11 +2745,6 @@ void CDox::handle_joystick_event (CJoystickAxisEvent *event)
 
 
   move_cursor (mo);
-//  if (mo != QTextCursor::NoMove)
-  //   {
-    //  cr.movePosition (mo, QTextCursor::MoveAnchor);
-     // d->textEdit->setTextCursor (cr);
-     //}
 }
 
 #endif
