@@ -22,7 +22,7 @@
 Copyright (C) 2006-2008 Trolltech ASA. All rights reserved.
 */
 
-/* 
+/*
 Diego Iastrubni <elcuco@kde.org> //some GPL'ed code from new-editor-diego-3, found on qtcentre forum
 */
 
@@ -44,18 +44,13 @@ code from qwriter:
 #include <QPlainTextEdit>
 #include <QSyntaxHighlighter>
 
-#if QT_VERSION >= 0x050700
-//#include <QtGamepad/QGamepad>
-//#include <QGamepadKeyNavigation>
-#endif
-
 
 #if QT_VERSION >= 0x050000
 #include <QRegularExpression>
 #endif
 
 
-#if defined(JOYSTICK_SUPPORTED)
+#if defined (JOYSTICK_SUPPORTED)
 #include "myjoystick.h"
 #endif
 
@@ -98,10 +93,6 @@ public:
   bool hl_brackets;
   bool draw_margin;
   bool draw_linenums;
-
- // bool use_hl_wrap;
- // bool wrap;
-
   bool auto_indent;
   bool spaces_instead_of_tabs;
   int tab_sp_width; //in spaces
@@ -117,7 +108,7 @@ public:
   void set_margin_pos (int mp);
   void set_hl_cur_line (bool enable);
   void set_hl_brackets (bool enable);
-  
+
   void set_word_wrap (bool wrap);
   bool get_word_wrap();
 
@@ -172,12 +163,10 @@ public:
 
   CDocument *document;
   bool casecare;
-
   int xml_format;
 
   QString exts;
   QString langs;
-
   QString cm_mult;
   QString cm_single;
 
@@ -214,9 +203,7 @@ public:
   void load_from_xml (const QString &fname);
 };
 
-
 #if QT_VERSION >= 0x050000
-
 class CSyntaxHighlighterQRegularExpression: public CSyntaxHighlighter
 {
   Q_OBJECT
@@ -338,27 +325,28 @@ public:
   QTimer *timer;
 
 
+
+
 #if defined(JOYSTICK_SUPPORTED)
+
   CJoystick *joystick;
-#endif
 
-  CDox();
-  ~CDox();
-
-
-#if defined(JOYSTICK_SUPPORTED)
   bool event (QEvent *ev);
   void handle_joystick_event (CJoystickAxisEvent *ev);
 #endif
 
 
+   CDox();
+  ~CDox();
+
+
   void update_project (const QString &fileName);
   void reload_recent_list();
   void add_to_recent (CDocument *d);
   void update_recent_menu();
   void update_current_files_menu();
 
-  void move_cursor (QTextCursor::MoveOperation mo); 
+  void move_cursor (QTextCursor::MoveOperation mo);
 
   Q_INVOKABLE CDocument* create_new();
   Q_INVOKABLE CDocument* open_file (const QString &fileName, const QString &codec);
@@ -379,7 +367,7 @@ public slots:
   void open_recent();
   void open_current();
 
-  void move_cursor_up(); 
+  void move_cursor_up();
   void move_cursor_down();
   void move_cursor_left();
   void move_cursor_right();
@@ -412,5 +400,4 @@ protected:
 
 };
 
-
 #endif
