@@ -1,5 +1,5 @@
  /**************************************************************************
- *   2007-2018 by Peter Semiletov                                          *
+ *   2007-2019 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -54,11 +54,14 @@ void CFMan::dir_up()
 
 void CFMan::nav (const QString &path)
 {
-  if (file_exists (path))
-     dir.setPath (path);
-  else
-      dir.setPath (QDir::homePath());
+  if (path.isEmpty())
+     return;
 
+  QString p = path;
+  if (path.startsWith ("file://"))
+     p = p.remove (0, 7);
+
+  dir.setPath (p);
   if (! dir.exists())
       return;
 
@@ -125,12 +128,12 @@ QDir::LocaleAware 0x40  Sort items appropriately using the current locale settin
 
 #endif
 
-  foreach (QFileInfo fi, lst)
-           add_entry (fi);
+  for (int i = 0; i < lst.size(); i++)
+       add_entry (lst.at(i));
 
   setModel (mymodel);
   connect (selectionModel(), SIGNAL(currentChanged (const QModelIndex &, const QModelIndex &)), this, SLOT(cb_fman_currentChanged (const QModelIndex &, const QModelIndex &)));
-  emit dir_changed (path);
+  emit dir_changed (p);
 }
 
 
@@ -260,7 +263,6 @@ CFMan::CFMan (QWidget *parent): QTreeView (parent)
   setModel (mymodel);
   setDragEnabled (true);
 
-
 #if QT_VERSION >= 0x050000
 
   header()->setSectionResizeMode (QHeaderView::ResizeToContents);
@@ -302,8 +304,7 @@ void CFMan::cb_fman_currentChanged (const QModelIndex &current, const QModelInde
 
   QString full_path = dir.path() + "/" + item_string;
 
-//  if (! is_dir (full_path))
-     emit current_file_changed (full_path, item_string);
+  emit current_file_changed (full_path, item_string);
 }
 
 
